//=============================================================================
//  Unified IO - C++ interface for industrial IO cards
//  Copyright (C) 2000, UAB BBDSoft ( http://www.bbdsoft.com/ )
//
// This material is provided "as is", with absolutely no warranty expressed
// or implied. Any use is at your own risk.
//
// Permission to use or copy this software for any purpose is hereby granted 
// without fee, provided the above notices are retained on all copies.
// Permission to modify the code and to distribute modified code is granted,
// provided the above notices are retained, and a notice that the code was
// modified is included with the above copyright notice.
//
//  The author of this program may be contacted at developers@bbdsoft.com
//=============================================================================


#ifndef _BTRACE_
   #include "btrace.hpp"
#endif

#ifndef _IOPORT_
   #include "ioport.hpp"
#endif

#ifndef _WINDOWS_
   #define WIN32_LEAN_AND_MEAN
   #include <windows.h>
#endif

#include <rtapi.h>

#ifndef _OSIFACE_
   #include "osiface.hpp"
#endif

using namespace Uniio;

//-----------------------------------------------------------------------------
IOPort::IOPort ( const unsigned inPortNumber
               , bool fWriteAccess
               )
   : thePortNumber ( inPortNumber )
   , theWriteAccess ( fWriteAccess )
{
BFUNCTRACE_DEVELOP ();
OSInterface::osinterface().enablePortIO ( thePortNumber, fWriteAccess );
} // end constructor


//-----------------------------------------------------------------------------
IOPort::~IOPort ()
{
BFUNCTRACE_DEVELOP ();
OSInterface::osinterface().disablePortIO ( thePortNumber );
} // end destructor


//-----------------------------------------------------------------------------
IOPort & IOPort::writeChar ( const char inValue )
{
BFUNCTRACE_DEVELOP ();
BASSERTTEXT (theWriteAccess, "Write access is not enabled on this port");

RtWritePortUchar ((PUCHAR)thePortNumber, (UCHAR)inValue);

return * this;
} // end IOPort::writeChar (..)


//-----------------------------------------------------------------------------
IOPort & IOPort::writeShort ( const short inValue )
{
BFUNCTRACE_DEVELOP ();
BASSERTTEXT (theWriteAccess, "Write access is not enabled on this port");

RtWritePortUshort ((PUSHORT)thePortNumber, (USHORT)inValue);

return * this;
} // end IOPort::writeShort (..)


//-----------------------------------------------------------------------------
IOPort & IOPort::writeLong ( const long inValue )
{
BFUNCTRACE_DEVELOP ();
BASSERTTEXT (theWriteAccess, "Write access is not enabled on this port");

RtWritePortUlong ((PULONG)thePortNumber, (ULONG)inValue);

return * this;
} // end IOPort::writeLong (..)


//-----------------------------------------------------------------------------
char IOPort::readChar () const
{
BFUNCTRACE_DEVELOP ();

return RtReadPortUchar ((PUCHAR)thePortNumber );
} // end IOPort::readChar () const



//-----------------------------------------------------------------------------
short IOPort::readShort () const
{
BFUNCTRACE_DEVELOP ();

return RtReadPortUshort ((PUSHORT)thePortNumber );
} // end IOPort::readShort () const


//-----------------------------------------------------------------------------
long IOPort::readLong () const
{
BFUNCTRACE_DEVELOP ();

return RtReadPortUlong ((PULONG)thePortNumber );
} // end IOPort::readLong () const
